[llvm-commits] CVS: llvm/lib/Transforms/Utils/Local.cpp

Michael Brukman brukman at cs.uiuc.edu
Tue May 20 16:02:06 PDT 2003


Changes in directory llvm/lib/Transforms/Utils:

Local.cpp updated: 1.5 -> 1.6

---
Log message:

Hopefully, the final fix for `[Pp]ropogate'.


---
Diffs of the changes:

Index: llvm/lib/Transforms/Utils/Local.cpp
diff -u llvm/lib/Transforms/Utils/Local.cpp:1.5 llvm/lib/Transforms/Utils/Local.cpp:1.6
--- llvm/lib/Transforms/Utils/Local.cpp:1.5	Mon Feb 24 14:48:32 2003
+++ llvm/lib/Transforms/Utils/Local.cpp	Tue May 20 16:01:18 2003
@@ -10,13 +10,13 @@
 #include "llvm/ConstantHandling.h"
 
 //===----------------------------------------------------------------------===//
 //  Local constant propogation...
 //
 
 // ConstantFoldInstruction - If an instruction references constants, try to fold
 // them together...
 //
-bool doConstantPropogation(BasicBlock::iterator &II) {
+bool doConstantPropagation(BasicBlock::iterator &II) {
   if (Constant *C = ConstantFoldInstruction(II)) {
     // Replaces all of the uses of a variable with uses of the constant.
     II->replaceAllUsesWith(C);
@@ -10,13 +10,13 @@
 
 //===----------------------------------------------------------------------===//
-//  Local constant propogation...
+//  Local constant propagation...
 //
 





More information about the llvm-commits mailing list